@@ -19,11 +19,11 @@ Queue::DBI - A queueing module with an emphasis on safety, using DBI as a storag
 
 =head1 VERSION
 
-Version 2.6.1
+Version 2.6.2
 
 =cut
 
-our $VERSION = '2.6.1';
+our $VERSION = '2.6.2';
 
 our $DEFAULT_QUEUES_TABLE_NAME = 'queues';
 
@@ -48,10 +48,21 @@ mechanism without having to use transactions.
 		'verbose'         => 1,
 	);
 
-	$queue->enqueue( $data );
+	# Store a complex data structure.
+	$queue->enqueue(
+		{
+			values => [ 1, 2, 3 ],
+			data   => { key1 => 1, key2 => 2 },
+		}
+	);
 
+	# Store a scalar, which must be passed by reference.
+	$queue->enqueue( \"Lorem ipsum dolor sit amet" );
+
+	# Process the queued elements one by one.
 	while ( my $queue_element = $queue->next() )
 	{
+		# Skip elements that cannot be locked.
 		next
 			unless $queue_element->lock();
 
@@ -337,11 +348,28 @@ sub count
 
 Adds a new element at the end of the current queue.
 
-	my $queue_element_id = $queue->enqueue( $data );
+	# Store a scalar by passing its reference.
+	my $queue_element_id = $queue->enqueue( \$string );
+	my $queue_element_id = $queue->enqueue( \"string" );
 
-The data passed can be a scalar or a reference to a complex data
-structure. There is no limitation on the type of data that can be stored
-as it is serialized for storage in the database.
+	# Store an array reference.
+	my $queue_element_id = $queue->enqueue( [ 1, 2, 3 ] );
+
+	# Store a hash reference.
+	my $queue_element_id = $queue->enqueue( { key => 123 } );
+
+	# Store a complex datastructure.
+	my $queue_element_id = $queue->enqueue(
+		{
+			values => [ 1, 2, 3 ],
+			data   => { key1 => 1, key2 => 2 },
+		}
+	);
+
+The data passed should be a reference to a scalar or a reference to a complex
+data structure, but you cannot pass a scalar directly. There is otherwise no
+limitation on the type of data that can be stored as it is serialized for
+storage in the database.
 
 =cut
 
@@ -353,6 +381,12 @@ sub enqueue
 	carp "Entering enqueue()." if $verbose;
 	carp "Data is: " . Dumper( $data ) if $verbose > 1;
 
+	# Make sure the data passed is a reference. We don't support scalars, as
+	# trying to store both scalars and references results in a mess documented in
+	# GH-3.
+	croak 'The data passed must be a reference, not a scalar'
+		if !ref( $data );
+
 	my $encoded_data = $self->freeze( $data );
 	croak 'The size of the data to store exceeds the maximum internal storage size available.'
 		if length( $encoded_data ) > $MAX_VALUE_SIZE;
@@ -1148,7 +1182,7 @@ I originally developed this project for ThinkGeek
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2014 Guillaume Aubert.
+Copyright 2009-2015 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
